CoerceIntValidator class

IntValidator that coerces input before validation.

Inheritance

Constructors

CoerceIntValidator([List<BaseNumberRule<int>> rules = const [], List<Transformer<int>> transformers = const [], bool isSecret = false])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isCompiled bool
True when this validator was produced by compile / ValidatorCompiler.
no setterinherited
isPure bool
True when no rules, transforms, or wrappers are attached.
no setterinherited
isSecret bool
finalinherited
rules List<BaseNumberRule<int>>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transformers List<Transformer<int>>
finalinherited

Methods

applyTransforms(dynamic initialValue, FlodPath path) → dynamic
inherited
compile() Validator<int>
12.3 — compiles into a cached, optimized validator tree.
inherited
copyWith({List<BaseNumberRule<int>>? rules, List<Transformer<int>>? transformers, bool? isSecret}) CoerceIntValidator
override
custom(bool predicate(int value), {required String code, String? message, Map<String, dynamic>? metaParams}) IntValidator
inherited
getFieldSchema(String key) Validator?
inherited
max(int maxBound, {String? code, String? message}) IntValidator
inherited
min(int minBound, {String? code, String? message}) IntValidator
inherited
multipleOf(int factor, {String? code, String? message}) IntValidator
inherited
negative({String? code, String? message}) IntValidator
inherited
nonNegative({String? code, String? message}) IntValidator
inherited
nonPositive({String? code, String? message}) IntValidator
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positive({String? code, String? message}) IntValidator
inherited
secret() CoerceIntValidator
override
stopOnFirstError() Validator<int>
inherited
strict() Validator<int>
inherited
toString() String
A string representation of this object.
inherited
transform<R>(R cb(int value)) Validator<R>
inherited
validate(dynamic value, {FlodPath path = const FlodPath([]), bool? abortEarly = false}) ParseResult<int>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited