rawValue property
dynamic
get
rawValue
Helper to access the real value inside the library (if needed for internal non-log computations)
Implementation
dynamic get rawValue => _rawValue;
Helper to access the real value inside the library (if needed for internal non-log computations)
dynamic get rawValue => _rawValue;