SuperRefineContext class final

Context passed to SuperRefineValidator / AsyncSuperRefineValidator callbacks. Allows attaching multiple targeted issues (Zod .superRefine() semantics).

Constructors

SuperRefineContext({required FlodPath basePath, required bool isSecret, required dynamic value})

Properties

basePath FlodPath
final
hashCode int
The hash code for this object.
no setterinherited
hasIssues bool
no setter
isSecret bool
final
issues List<FlodError>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
final

Methods

addIssue({List<String>? path, required String code, String? message, Map<String, dynamic>? params}) → void
Adds a validation issue, optionally scoped to a nested path segment list.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited