JsonGuardOptions class

Security limits applied before schema validation.

Rejects oversized or structurally dangerous JSON payloads (prototype pollution keys, excessive depth, etc.).

Constructors

JsonGuardOptions({int maxDepth = 32, int maxKeys = 1000, int maxStringLength = 100000, int maxArrayLength = 10000, bool blockPrototypeKeys = true})
const

Properties

blockPrototypeKeys bool
final
hashCode int
The hash code for this object.
no setterinherited
maxArrayLength int
final
maxDepth int
final
maxKeys int
final
maxStringLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited